"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.publicAPI = void 0;
const axios_1 = __importDefault(require("axios"));
/**
 * Public API - Use the official API From trakteer
 * @see https://trakteer.id/manage/api-trakteer
 */
class publicAPI {
    constructor(apiKey) {
        this.APIkey = apiKey;
    }
    /**
     * API ini digunakan untuk melihat jumlah unit trakteer-an yang telah diberikan oleh supporter (berdasarkan email) selama 30 hari terakhir.
     * @param email Supporter Email
     * @returns is unknown, please open issue if you have one example.
     */
    quantityGiven(email) {
        return __awaiter(this, void 0, void 0, function* () {
            const req = yield axios_1.default.post("https://api.trakteer.id/v1/public/quantity-given", {
                email
            }, {
                headers: {
                    Accept: "application/json",
                    "X-Requested-With": "XMLHttpRequest",
                    "key": this.APIkey,
                }
            });
            return req.data;
        });
    }
    /**
     * API ini digunakan untuk mendapatkan riwayat trakteer-an yang diberikan oleh supporter.
     * @param limit Number of records
     * @param page Current page in paginated records
     * @returns support history
     */
    supportHistory(limit = 10, page = 1) {
        return __awaiter(this, void 0, void 0, function* () {
            const req = yield axios_1.default.get(`https://api.trakteer.id/v1/public/support-history?limit=${limit}&page=${page}`, {
                headers: {
                    Accept: "application/json",
                    "X-Requested-With": "XMLHttpRequest",
                    "key": this.APIkey,
                }
            });
            return req.data;
        });
    }
}
exports.publicAPI = publicAPI;
