/// <reference types="node" />
import createHttpsProxyAgent, { HttpsProxyAgent } from "https-proxy-agent";
import { EventEmitter, WebSocket } from "ws";
import { Goal, leaderboard, supporter } from "../interfaces";
interface ClientEvents {
    'donation': (message: JSON) => void;
    'connect': (timestamp: Date) => void;
    'disconnect': (timestamp: Date) => void;
}
export declare interface Client {
    on<U extends keyof ClientEvents>(event: U, listener: ClientEvents[U]): this;
}
export declare class Client extends EventEmitter {
    username: string;
    streamKey: `trstream-${string}`;
    userId: string | undefined;
    client: WebSocket;
    agent: HttpsProxyAgent | undefined;
    private messages;
    private pingInterval;
    /**
     * Client Class
     * @param pageID should be the trakteer page id (NOT Username). check pageID in https://trakteer.id/manage/my-page/settings
     * @param streamKey should be `trstream-xxx`. check key in https://trakteer.id/manage/stream-settings
     */
    constructor(pageID: string, streamKey: `trstream-${string}`, proxy?: string | createHttpsProxyAgent.HttpsProxyAgentOptions, userAgent?: string);
    /**
     * Get Donation Leaderboard
     * @param dayInterval Get Donation from last x day
     * @param maxAmount Max Amount of leadedrboard
     * @param sortBy Sort By Rupiah amount or Unit Amount
     * @returns Leaderboard
     */
    getLeaderboard(dayInterval?: number, maxAmount?: number, sortBy?: "nominal" | "unit"): Promise<leaderboard>;
    /**
     * Get Supporter from all time
     * @param amount Amount of supporter to get
     * @returns supporter list
     */
    getSupporter(amount?: number): Promise<supporter[]>;
    /**
     * Get Goal
     * @returns Goal
     */
    getGoal(): Promise<Goal>;
    /**
     *
     * @param cb This will triggered when The client is ready.
     * @deprecated This will removed on later version, please use `client.on("open")` instead.
     */
    onOpen(cb: CallableFunction): void;
    /**
     *
     * @param cb This will triggered when donation is detected
     * @deprecated This will removed on later version, please use `client.on("donation")` instead.
     */
    onDonation(cb: CallableFunction): void;
}
export {};
